<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>NotificationActionsComboWidget</name>
    <message>
        <location filename="../notificationwidgets.cpp" line="103"/>
        <source>Actions:</source>
        <translation>פעולות:</translation>
    </message>
    <message>
        <location filename="../notificationwidgets.cpp" line="122"/>
        <source>OK</source>
        <translation>אישור</translation>
    </message>
</context>
<context>
    <name>Notifyd</name>
    <message>
        <location filename="../notifyd.cpp" line="227"/>
        <source>Clear All</source>
        <translation>לפנות הכול</translation>
    </message>
    <message>
        <location filename="../notifyd.cpp" line="235"/>
        <source>Options</source>
        <translation>אפשרויות</translation>
    </message>
    <message numerus="yes">
        <location filename="../notifyd.cpp" line="242"/>
        <location filename="../notifyd.cpp" line="300"/>
        <location filename="../notifyd.cpp" line="320"/>
        <source>%n Unattended Notification(s)</source>
        <translation>
            <numerusform>%n התראות שלא התייחסת אליהן</numerusform>
            <numerusform>%n התראות שלא התייחסת אליהן</numerusform>
        </translation>
    </message>
</context>
</TS>
